@@ -17,6 +17,7 @@
  */
 
 #include "mainwindow.h"
+#include "ddlog.h"
 
 #include <DSysInfo>
 #include <QDesktopServices>
@@ -36,7 +37,7 @@ MainWindow::MainWindow(DWidget *parent)
     , m_settings(new QSettings("deepin", "dde-introduction"))
     , m_title(new DLabel(this))
 {
-    qInfo() << "Current cpu architecture : " << QSysInfo::currentCpuArchitecture();
+    qCInfo(app) << "Current CPU architecture:" << QSysInfo::currentCpuArchitecture();
     setWindowFlags(Qt::CustomizeWindowHint);
 
     titlebar()->setMenuVisible(false);
@@ -55,8 +56,10 @@ MainWindow::MainWindow(DWidget *parent)
     m_isFirst = m_settings->value("IsFirst", true).toBool();
     m_settings->setValue("IsFirst", false);
 
+    qCDebug(app) << "Initializing MainWindow components";
     initUI();
     initConnect();
+    qCDebug(app) << "MainWindow initialization completed";
 
     //设置首次启动的tab顺序
     setTabOrder(m_previousBtn, m_nextBtn);
@@ -66,6 +69,7 @@ MainWindow::MainWindow(DWidget *parent)
 
 MainWindow::~MainWindow()
 {
+    qCInfo(app) << "MainWindow destructor called";
     if (m_current) {
         delete m_current;
         m_current = nullptr;
@@ -84,6 +88,7 @@ MainWindow::~MainWindow()
 
 void MainWindow::delayInitVideo()
 {
+    qCDebug(app) << "Delaying video initialization";
     m_delayInit = true;
     QTimer::singleShot(1500, this, [ this ]() {
         WidgetManager::Instance()->delayInit();
@@ -131,7 +136,10 @@ void MainWindow::resizeEvent(QResizeEvent *event)
 *******************************************************************************/
 void MainWindow::previous()
 {
+    qCDebug(app) << "Previous button clicked, current index:" << m_index;
+
     if (m_currentAni->state() == QPropertyAnimation::Running) {
+        qCDebug(app) << "Animation is running, skip previous operation";
         return;
     }
 
@@ -157,6 +165,7 @@ void MainWindow::previous()
     m_lastOpacityAni->setStartValue(1);
     m_lastOpacityAni->setEndValue(0);
 
+    qCDebug(app) << "Starting previous page animation";
     m_currentAni->start();
 //    m_currentOpacityAni->start();
     m_lastAni->start();
@@ -171,7 +180,10 @@ void MainWindow::previous()
 *******************************************************************************/
 void MainWindow::next()
 {
+    qCDebug(app) << "Next button clicked, current index:" << m_index;
+
     if (m_currentAni->state() == QPropertyAnimation::Running || m_loadVideoLoop.isRunning()) {
+        qCDebug(app) << "Animation or video loading is running, skip next operation";
         return;
     }
 
@@ -202,14 +214,17 @@ void MainWindow::next()
     m_currentOpacityAni->setStartValue(0.5);
     m_currentOpacityAni->setEndValue(1);
 
+    qCDebug(app) << "Starting next page animation";
     m_currentAni->start();
 //    m_currentOpacityAni->start();
     m_lastAni->start();
     m_lastOpacityAni->start();
+    qCDebug(app) << "Exit next(), switched to index:" << m_index;
 }
 
 void MainWindow::finishedAndClose()
 {
+    qCDebug(app) << "Finished and closing window";
     if (m_isFirst) {
         QDBusInterface networkInterface("org.freedesktop.NetworkManager",
                                  "/org/freedesktop/NetworkManager",
@@ -250,6 +265,7 @@ void MainWindow::slotTheme()
 
 void MainWindow::initUI()
 {
+    qCDebug(app) << "Initializing MainWindow UI";
     //设置圆角
 //    DPlatformWindowHandle handle(this);
     m_fakerWidget = new DWidget(this);
@@ -372,6 +388,7 @@ void MainWindow::initUI()
 
 void MainWindow::initConnect()
 {
+    qCDebug(app) << "Initializing MainWindow signal connections";
     //主题变化响应
     connect(m_nextBtn, &DSuggestButton::clicked, this, &MainWindow::next);
     connect(m_nextBtn, &DSuggestButton::clicked, WidgetManager::Instance(), &WidgetManager::delayInit);
@@ -410,6 +427,7 @@ void MainWindow::bindAnimation()
 *******************************************************************************/
 void MainWindow::updateModule(const int index)
 {
+    qCDebug(app) << "Updating module to index:" << index;
 //    if (m_videoWidgetList.size() <= index)
 //        m_loadVideoLoop.exec();
     m_doneBtn->hide();
@@ -444,6 +462,7 @@ void MainWindow::updateModule(const int index)
         m_previousBtn->hide();
 
     bindAnimation();
+    qCDebug(app) << "Animation bound for current and last widgets";
 }
 
 /*******************************************************************************
@@ -454,6 +473,8 @@ void MainWindow::updateModule(const int index)
 *******************************************************************************/
 void MainWindow::animationHandle()
 {
+    qCDebug(app) << "Animation completed for index:" << m_index;
+
     VideoWidget *video = dynamic_cast<VideoWidget *>(dynamic_cast<BaseModuleWidget *>(m_last)->getModel());
     if (video)
         video->pause();
